==> email_validator-8.x-1.0.tar.gz: email_validator/src/EVA.php <==
<?php

namespace Drupal\email_validator;

use Drupal\Component\Utility\EmailValidator;
use Egulias\EmailValidator\Validation\EmailValidation;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use GuzzleHttp\Exception\RequestException;
use Drupal\Component\Serialization\Json;
use Psr\Log\LoggerInterface;

/**
 * @file
 * Check the email for email_verify module.
 */

/**
 * Email Validation service.
 */
class EVA extends EmailValidator {

  /**
   * The logger service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The cache.default cache backend.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cacheBackend;

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * Constructs a new EVA object.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   The configuration factory.
   */
  public function __construct(
    LoggerInterface $logger,
    CacheBackendInterface $cacheBackend,
    ConfigFactoryInterface $config
  ) {
    parent::__construct();
    $this->cache = $cacheBackend;
    $this->logger = $logger;
    $this->config = $config;

    // Get Configs defined by user.
    $defaults = $this->config->get('email_validator.settings');
    // General Settings.
    $this->url = 'https://e-va.io/api/email/validate/';
    $this->token = $defaults->get('general')['api_key'];
    // Custom Forms to validate.
    $this->custom_forms = NULL;
    if (!$defaults->get('configuration')['protect_all']) {
      $this->custom_forms = array_filter($defaults->get('configuration')['forms']);
    }
    // Protection Settings.
    $this->mail_states = NULL;
    if ($this->custom_forms && !$defaults->get('protection')['states_all']) {
      $this->mail_states = $defaults->get('protection')['email_states'];
    }
    // Log Settings.
    $this->log_reject = $defaults->get('logs')['wrong_emails'];
    $this->bypass = $defaults->get('logs')['system_down'];
  }

  /**
   * A simple controller method that will handle the get and post requests.
   */
  public function curlRequest($email = NULL) {
    // Try to load the files from cache.
    if ($data = $this->readCacheItem($email)) {
      return $this->checkIsValid($data, $email);
    }
    // Init Http Connection Client.
    $client = \Drupal::service('http_client');
    $options = [
      'headers' => [
        'api-key' => $this->token,
        'CB-ACCESS-TIMESTAMP' => time(),
        'user-agent' => 'Square-bit email validation',
        'content-type' => 'application/json',
      ],
    ];
    // Call the EVA API.
    try {
      $request = $client->request('GET', $this->url . $email, $options);
      if (!empty($response = $request->getBody()->getContents())) {
        $data = Json::decode($response);
        if ($data['status'] === 'nok') {
          $this->logger->warning("EVA can't validate the email @email. Error message: %msg", [
            '@email' => $email,
            '%msg' => $json['message'],
          ]);
        }
        elseif ($data['status'] === 'ok') {
          // Get the data given. Check the status.
          // Save Cache.
          $this->createCacheItem($data, $email);
          return $this->checkIsValid($data, $email);
        }
      }
    }
    catch (RequestException $e) {
      $this->logger->error('There was a problem with EVA API, after trying to validate the e-mail @email. The error: @error', [
        '@email' => $email,
        '@error' => $e->getMessage(),
      ]);
    }

    return (bool) $this->bypass;
  }

  /**
   * Handle function that will get the request and take care the retrieved data.
   */
  private function checkIsValid($data, $email) {
    $email_state = $this->convertEmailStates($data['state']);
    if (is_array($this->mail_states) && in_array($email_state, $this->mail_states)) {
      return TRUE;
    }
    // If user choose to log reject mails.
    if ($this->log_reject) {
      $this->logger->info('EVA has rejected @email (@state) with the following message: %msg', [
        '@email' => $email,
        '@state' => $data['state'],
        '%msg' => $data['message'],
      ]);
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function isValid($email, EmailValidation $email_validation = NULL, $custom_form = FALSE) {
    parent::isValid($email, $email_validation);

    // USE EVA.
    if ((!$this->custom_forms && $this->mail_states) || ($custom_form)) {
      if (($api_status = $this->curlRequest($email)) !== TRUE) {
        return FALSE;
      }
    }

    return TRUE;
  }

  /**
   * Create a new cache item with specified expiration.
   */
  private function createCacheItem($data, $cid) {
    if ($cid) {
      $expiration = time() + 3600;
      // Set the expiration to the actual Unix timestamp of the end of the
      // required interval. Also add a tag to it to be able to clear caches more
      // precise.
      $this->cache->set('email_validator_api:' . $cid, $data, $expiration, []);
    }
  }

  /**
   * Read an item from cache.
   */
  private function readCacheItem($cid) {
    if ($cid && $cache = $this->cache->get('email_validator_api:' . $cid)) {
      return $cache->data;
    }
    return FALSE;
  }

  /**
   * Convert readable text states into some int value.
   */
  private function convertEmailStates($text_state) {
    switch ($text_state) {
      case 'Safe':
        $state = 0;
        break;

      case 'Unknown':
        $state = 1;
        break;

      case 'Invalid':
        $state = 2;
        break;

      case 'Risky':
        $state = 3;
        break;

      default:
        $state = 1;
        break;
    }
    return $state;
  }

  /**
   * Check if EVA should validate this some specific form.
   */
  public function validateForm($form_id) {
    if (!empty($this->custom_forms) && array_key_exists($form_id, $this->custom_forms)) {
      return TRUE;
    }
    return FALSE;
  }

}

==> email_validator-8.x-1.2.tar.gz: email_validator/src/EVA.php <==
<?php

namespace Drupal\email_validator;

use Drupal\Component\Utility\EmailValidator;
use Egulias\EmailValidator\Validation\EmailValidation;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use GuzzleHttp\Exception\RequestException;
use Drupal\Component\Serialization\Json;
use Psr\Log\LoggerInterface;
use GuzzleHttp\Client;

/**
 * @file
 * Check the email for email_verify module.
 */

/**
 * Email Validation service.
 */
class EVA extends EmailValidator {

  /**
   * The logger service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The cache.default cache backend.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cacheBackend;

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * Guzzle\Client instance.
   *
   * @var \Guzzle\Client
   */
  protected $httpClient;

  /**
   * Constructs a new EVA object.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   The configuration factory.
   * @param \GuzzleHttp\Client $http_client
   *   The http_client.
   */
  public function __construct(
    LoggerInterface $logger,
    CacheBackendInterface $cacheBackend,
    ConfigFactoryInterface $config,
    Client $http_client
  ) {
    parent::__construct();
    $this->cache = $cacheBackend;
    $this->logger = $logger;
    $this->config = $config;
    $this->httpClient = $http_client;

    // Get Configs defined by user.
    $defaults = $this->config->get('email_validator.settings');
    // General Settings.
    $this->url = 'https://e-va.io/api/email/validate/';
    $this->token = $defaults->get('general')['api_key'];
    // Custom Forms to validate.
    $this->custom_forms = NULL;
    if (!$defaults->get('configuration')['protect_all']) {
      $this->custom_forms = array_filter($defaults->get('configuration')['forms']);
    }
    // Protection Settings.
    $this->mail_states = NULL;
    if ($this->custom_forms && !$defaults->get('protection')['states_all']) {
      $this->mail_states = $defaults->get('protection')['email_states'];
    }
    // Log Settings.
    $this->log_reject = $defaults->get('logs')['wrong_emails'];
    $this->bypass = $defaults->get('logs')['system_down'];
  }

  /**
   * A simple controller method that will handle the get and post requests.
   */
  public function curlRequest($email = NULL) {
    // Try to load the files from cache.
    if ($data = $this->readCacheItem($email)) {
      return $this->checkIsValid($data, $email);
    }

    $options = [
      'headers' => [
        'api-key' => $this->token,
        'CB-ACCESS-TIMESTAMP' => time(),
        'user-agent' => 'Square-bit email validation',
        'content-type' => 'application/json',
      ],
    ];
    // Call the EVA API.
    try {
      $request = $this->httpClient->request('GET', $this->url . $email, $options);
      if (!empty($response = $request->getBody()->getContents())) {
        $data = Json::decode($response);
        if ($data['status'] === 'nok') {
          $this->logger->warning("EVA can't validate the email @email. Error message: %msg", [
            '@email' => $email,
            '%msg' => $data['message'],
          ]);
        }
        elseif ($data['status'] === 'ok') {
          // Get the data given. Check the status.
          // Save Cache.
          $this->createCacheItem($data, $email);
          return $this->checkIsValid($data, $email);
        }
      }
    }
    catch (RequestException $e) {
      $this->logger->error('There was a problem with EVA API, after trying to validate the e-mail @email. The error: @error', [
        '@email' => $email,
        '@error' => $e->getMessage(),
      ]);
    }

    return (bool) $this->bypass;
  }

  /**
   * Handle function that will get the request and take care the retrieved data.
   */
  private function checkIsValid($data, $email) {
    $email_state = $this->convertEmailStates($data['state']);
    if (is_array($this->mail_states) && in_array($email_state, $this->mail_states)) {
      return TRUE;
    }
    // If user choose to log reject mails.
    if ($this->log_reject) {
      $this->logger->info('EVA has rejected @email (@state) with the following message: %msg', [
        '@email' => $email,
        '@state' => $data['state'],
        '%msg' => $data['message'],
      ]);
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function isValid($email, EmailValidation $email_validation = NULL, $custom_form = FALSE) {
    parent::isValid($email, $email_validation);

    // USE EVA.
    if ((!$this->custom_forms && $this->mail_states) || ($custom_form)) {
      if ($this->curlRequest($email) !== TRUE) {
        return FALSE;
      }
    }

    return TRUE;
  }

  /**
   * Create a new cache item with specified expiration.
   */
  private function createCacheItem($data, $cid) {
    if ($cid) {
      $expiration = time() + 3600;
      // Set the expiration to the actual Unix timestamp of the end of the
      // required interval. Also add a tag to it to be able to clear caches more
      // precise.
      $this->cache->set('email_validator_api:' . $cid, $data, $expiration, []);
    }
  }

  /**
   * Read an item from cache.
   */
  private function readCacheItem($cid) {
    if ($cid && $cache = $this->cache->get('email_validator_api:' . $cid)) {
      return $cache->data;
    }
    return FALSE;
  }

  /**
   * Convert readable text states into some int value.
   */
  private function convertEmailStates($text_state) {
    switch ($text_state) {
      case 'Safe':
        $state = 0;
        break;

      case 'Unknown':
        $state = 1;
        break;

      case 'Invalid':
        $state = 2;
        break;

      case 'Risky':
        $state = 3;
        break;

      default:
        $state = 1;
        break;
    }
    return $state;
  }

  /**
   * Check if EVA should validate this some specific form.
   */
  public function validateForm($form_id) {
    if (!empty($this->custom_forms) && array_key_exists($form_id, $this->custom_forms)) {
      return TRUE;
    }
    return FALSE;
  }

}
